.. GeoModels documentation master file, created by
   sphinx-quickstart on Tue Dec 17 08:29:06 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


:author:    Antonio Valentino
:copyright: 2019-2025 Antonio Valentino
:license:   MIT
:version:   |release|
:url:       https://github.com/avalentino/geomodels


=======================
GeoModels Documentation
=======================

.. toctree::
   :maxdepth: 3

   quickstart
   installation
   cli
   API Reference <api/geomodels>
   NEWS


.. only:: html

   Indices and tables
   ==================

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
